import { ESupportedLocales } from '@cloudflare/intl-core';
/**
 * Moment formatters per-locale examples.
 *
 *   en-US
 * -------------------
 * LongDate:            September 4, 1986
 * ShortDate:           Sep 4, 1986
 * Time:                1:30 PM
 * DateTime:            September 4, 1986
 * ISO8601:             1986-09-04T13:30:00-07:00
 * LongDayMonth:        4 September
 * ShortDayMonth:       4 Sep
 *
 *   de-DE
 * -------------------
 * LongDate:            4. September 1986
 * ShortDate:           4. Sep. 1986
 * Time:                13:30
 * DateTime:            4. September 1986 13:30
 * ISO8601:             1986-09-04T13:30:00-07:00
 * LongDayMonth:        4 September
 * ShortDayMonth:       4 Sep.
 */
export declare enum DateFormatters {
    LongDate = "LL",
    ShortDate = "ll",
    Time = "LT",
    DateTime = "LLL",
    ISO8601 = "YYYY-MM-DDTHH:mm:ssZ",
    LongDayMonth = "D MMMM",
    ShortDayMonth = "D MMM",
    DateTimeWithSeparators = "L LT",
    DateTimeSecondsWithSeparators = "L LTS"
}
export declare const formatDate: (value: any, formatter: DateFormatters) => string;
export declare const localizeNumberWithPrecision: (number: number, locale?: ESupportedLocales) => string;
export declare const formatNumber: (number: number, locale?: ESupportedLocales, useSI?: boolean, decimalPlaces?: number, trimInsignificantZeros?: boolean) => string;
export declare type CurrencyOptions = {
    locale: ESupportedLocales;
};
export declare const formatCurrency: (value?: string | number | undefined, options?: CurrencyOptions) => string;
/**
 * @param {Number} number
 * @param {String} locale
 * @param {Boolean} [includeDecimals]
 * @return {String}
 */
export declare const formatBytes: (number: number, locale: ESupportedLocales | undefined, includeDecimals: boolean) => string;
/**
 * @param {Number} number
 * @param {String} locale
 * @param {Boolean} [useSI]
 * @param {Number} [decimalPlaces]
 * @param {Boolean} [trimInsignificantZeros]
 * @return {String}
 */
export declare const formatNumberForAnalytics: (number: number, locale?: ESupportedLocales, useSI?: boolean, decimalPlaces?: number, trimInsignificantZeros?: boolean) => string;
